@@ -180,28 +180,11 @@ class ETTrainer:
 
     def iteration(self, batch) -> dict:
         r"""
-        Left for user to implement one mini-bath iteration:
-        Example:{
-                    inputs = batch['input'].to(self.device['gpu']).float()
-                    labels = batch['label'].to(self.device['gpu']).long()
-                    out = self.nn['model'](inputs)
-                    loss = F.cross_entropy(out, labels)
-                    out = F.softmax(out, 1)
-                    _, pred = torch.max(out, 1)
-                    sc = self.new_metrics()
-                    sc.add(pred, labels)
-                    avg = self.new_averages()
-                    avg.add(loss.item(), len(inputs))
-                    return {'loss': loss, 'averages': avg, 'output': out, 'metrics': sc, 'predictions': pred}
-                }
-        Note: loss, averages, and metrics are required, whereas others are optional
-            -we will have to do backward on loss
-            -we need to keep track of loss
-            -we need to keep track of metrics
+        Note: 'loss' adn 'meter' keys are required in the return dict, whereas others are optional
         """
         return {}
 
-    def save_predictions(self, dataset, its) -> dict:
+    def save_predictions(self, dataset, its):
         r"""
         If one needs to save complex predictions result like predicted segmentations.
          -Especially with U-Net architectures, we split images and train.
@@ -209,7 +192,7 @@ class ETTrainer:
         the argument 'its' will receive all the patches of single image at a time.
         From there, we can recreate the whole image.
         """
-        return {}
+        return None
 
     def evaluation(self,
                    epoch=1,
@@ -227,10 +210,10 @@ class ETTrainer:
         info(f'{mode} ...', self.args['verbose'])
 
         def _update_scores(_out, _it, _meter):
-            if _out is None:
-                _out = {}
-            _m = _out.get('meter', _it['meter'])
-            _meter.accumulate(_m.averages, _m.metrics)
+            if isinstance(_out, _metrics.ETMeter):
+                _meter.accumulate(_out.averages, _out.metrics)
+            else:
+                _meter.accumulate(_it['meter'].averages, _it['meter'].metrics)
 
         with _torch.no_grad():
             for loader in dataloaders:
